Package: clootl
Title: Fetch and Explore the Cornell Lab of Ornithology Open Tree of
        Life Avian Phylogeny
Version: 0.1.4
Authors@R: c(
  person("Eliot", "Miller", role=c("aut", "cre"), email = "clootlmaintainers@gmail.com"),
  person("Emily Jane", "McTavish", role=c("aut")),
  person("Luna L.", "Sanchez Reyes", role=c("ctb", "aut")))
Maintainer: Eliot Miller <clootlmaintainers@gmail.com>
URL: https://github.com/eliotmiller/clootl
BugReports: https://github.com/eliotmiller/clootl/issues
Depends: R (>= 4.3.0), ape
Imports: dplyr, RCurl, jsonlite
LazyData: true
LazyDataCompression: xz
Description: Fetches the Cornell Lab of Ornithology Open Tree of Life (clootl) tree in a specified taxonomy. Optionally prune it to a given set of study taxa. Provide a recommended citation list for the studies that informed the extracted tree. Tree generated as described in McTavish et al. (2024) <doi:10.1101/2024.05.20.595017>.
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: rmarkdown, testthat (>= 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-23 17:13:30 UTC; luna
Author: Eliot Miller [aut, cre],
  Emily Jane McTavish [aut],
  Luna L. Sanchez Reyes [ctb, aut]
Repository: CRAN
Date/Publication: 2026-04-23 17:30:02 UTC
Built: R 4.6.0; ; 2026-04-26 12:12:46 UTC; unix
