# Generated by roxygen2: do not edit by hand

export(extractTree)
export(getCitations)
export(get_avesdata_repo)
export(get_avesdata_repo_path)
export(sampleTrees)
export(set_avesdata_repo_path)
export(taxonomyGet)
import(ape)
importFrom(RCurl,postForm)
importFrom(dplyr,group_by)
importFrom(dplyr,summarize)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
