% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{set_avesdata_repo_path}
\alias{set_avesdata_repo_path}
\title{Set path to Aves Data folder}
\usage{
set_avesdata_repo_path(path, overwrite = FALSE, warn = TRUE)
}
\arguments{
\item{path}{A character vector with the path to the Aves Data folder}

\item{overwrite}{Boolean, default to \code{FALSE}, does not overwrite an existing Aves Data folder. Set to \code{TRUE} to overwrite.}

\item{warn}{Boolean, default to \code{TRUE}, Warns if path does not exist.
Set to FALSE and path="" to unset path.}
}
\value{
No return value, called to set the path to the Aves Data folder.
}
\description{
Set path to Aves Data folder already somewhere on your computer
}
\details{
Based on https://github.com/CornellLabofOrnithology/auk/blob/main/R/auk-set-ebd-path.r
Use this function to manually set or update location of a downloaded AvesData folder from https://github.com/McTavishLab/AvesData.
When \code{AVESDATA_PATH} is set, the data_path in any clootl functions with a \code{data_path} argument will default to this value.
}
\examples{
\dontrun{
set_avesdata_repo_path("/home/ejmctavish/AvesData")
}
}
